<?php

namespace Clientexec\Utils;

use Clientexec\Utils\Form as Form;

class CustomFieldHelper
{

    public function getLabel($field)
    {
        $type = '';
        if ($field['type'] == typeCHECK) {
            $type = 'checkbox';
        }
        return Form::label($field['name'], $field['name'], $type);
    }

    public function getMarkup($field)
    {
        $controlId = $field['id'];
        if (is_numeric($field['id'])) {
            $controlId = 'CT_' . $field['id'];
        }
        $required = ($field['isrequired'] == 1 ? 'true' : 'false');

        switch ($field['fieldtype']) {
            case 'subdomain':
                foreach ($field['subdomains'] as $subDomain) {
                    $field['dropdownoptions'][] = [$subDomain, '.' . $subDomain];
                }

                $html = [];
                $html[] = '<div class="input-group">';
                $html[] = Form::text(
                    $controlId,
                    $field['value'],
                    [
                        'id' => $controlId,
                        'class' => 'form-control subdomain-input',
                        'data-parsley-required' => $required,
                        'data-parsley-pattern' => '^([-0-9A-Za-z]+)$',
                        'data-parsley-errors-container' => "#subDomainGroup",
                    ]
                );
                $html[] = '<div class="input-group-append subdomain">';
                $html[] = Form::select(
                    'subdomaintld_' . $controlId,
                    $field['dropdownoptions'],
                    '',
                    [
                        'id' => $controlId . '-tld',
                        'class' => [
                            'form-control',
                            'searchSelect2',
                            'subdomain-select'
                        ]
                    ]
                );
                $html[] = '</div>';
                $html[] = '</div>';
                return implode("\n", $html);

                break;

            case TYPEPASSWORD:
                return Form::password(
                    $controlId,
                    '',
                    [
                        'id' => $controlId,
                        'class' => 'form-control',
                        'data-parsley-required' => $required
                    ]
                );
                break;

            case typeADDRESS:
            case typeORGANIZATION:
            case typeSTATE:
            case typeCITY:
            case typeZIPCODE:
            case typeFIRSTNAME:
            case typeLASTNAME:
            case typePHONENUMBER:
            case typeTEXTFIELD:
                return Form::text(
                    $controlId,
                    $field['value'],
                    [
                        'id' => $controlId,
                        'class' => 'form-control',
                        'data-parsley-required' => $required
                    ]
                );
                break;

            case typeTEXTAREA:
                return Form::textarea(
                    $controlId,
                    $field['value'],
                    [
                        'id' => $controlId,
                        'class' => 'form-control',
                        'style' => 'width: 100%; height:100px',
                        'data-parsley-required' => $required
                    ]
                );
                break;

            case typeEMAIL:
                return Form::email(
                    $controlId,
                    $field['value'],
                    [
                        'id' => $controlId,
                        'class' => 'form-control',
                        'data-parsley-required' => $required
                    ]
                );
                break;

            case TYPE_ALLOW_EMAIL:
            case typeYESNO:
                if (is_string($field['dropdownoptions'])) {
                    $field['dropdownoptions'] = [];
                }
                $field['dropdownoptions'][] = [0, 'No'];
                $field['dropdownoptions'][] = [1, 'Yes'];
                return Form::select(
                    $controlId,
                    $field['dropdownoptions'],
                    $field['value'],
                    [
                        'id' => $controlId,
                        'class' => [
                            'form-control',
                            'normalSelect2'
                        ]
                    ]
                );
                break;
            case typeLANGUAGE:
            case typePRODUCTSTATUS:
            case typeCOUNTRY:
            case typeDROPDOWN:
                return Form::select(
                    $controlId,
                    $field['dropdownoptions'],
                    $field['value'],
                    [
                        'id' => $controlId,
                        'class' => [
                            'form-control',
                            'searchSelect2'
                        ]
                    ]
                );
                break;
            case typeVATNUMBER:
                return Form::vat(
                    $controlId,
                    $field['value'],
                    [
                        'id' => $controlId,
                        'class' => 'form-control',
                        'data-parsley-required' => $required
                    ]
                );

            case typeDATE:
                return Form::date(
                    $controlId,
                    $field['value'],
                    [
                        'id' => $controlId,
                        'class' => ['form-control'],
                        'data-parsley-required' => $required
                    ]
                );
                break;

            case typeCHECK:
                return Form::checkbox(
                    $controlId,
                    $field['value'],
                    [
                        'id' => $controlId,
                        'class' => 'form-check-input',
                        'data-parsley-required' => $required
                    ]
                );
                break;

            default:
                \CE_Lib::log(4, 'Unknown Field Type: ');
                \CE_Lib::log(4, $field);
                break;
        }
    }
}
